==> haskell-bytestring-handle-0.1.0.6-45-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bytestring-handle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bytestring-handle
version:              0.1.0.6
visibility:           public
id:                   bytestring-handle-0.1.0.6-GCAfdbmc4hv6blZAKetrDE
key:                  bytestring-handle-0.1.0.6-GCAfdbmc4hv6blZAKetrDE
license:              BSD-3-Clause
maintainer:           Ganesh Sittampalam <ganesh@earth.li>
author:               Ganesh Sittampalam
homepage:             http://hub.darcs.net/ganesh/bytestring-handle
synopsis:             ByteString-backed Handles
category:             System
abi:                  916f01728105bc1b3b26b715584f9f56
exposed:              True
exposed-modules:      Data.ByteString.Handle
hidden-modules:
    Data.ByteString.Handle.Read Data.ByteString.Handle.Write

import-dirs:          /usr/lib/ghc-8.10.4/site-local/bytestring-handle-0.1.0.6
library-dirs:         /usr/lib/ghc-8.10.4/site-local/bytestring-handle-0.1.0.6
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.4/bytestring-handle-0.1.0.6

hs-libraries:         HSbytestring-handle-0.1.0.6-GCAfdbmc4hv6blZAKetrDE
depends:              base-4.14.1.0 bytestring-0.10.12.0
haddock-interfaces:
    /usr/share/doc/haskell-bytestring-handle/html/bytestring-handle.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-handle/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bytestring-handle-0.1.0.6-46-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bytestring-handle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bytestring-handle
version:              0.1.0.6
visibility:           public
id:                   bytestring-handle-0.1.0.6-5Wc1ZXhmhAZ4GPJQSe165h
key:                  bytestring-handle-0.1.0.6-5Wc1ZXhmhAZ4GPJQSe165h
license:              BSD-3-Clause
maintainer:           Ganesh Sittampalam <ganesh@earth.li>
author:               Ganesh Sittampalam
homepage:             http://hub.darcs.net/ganesh/bytestring-handle
synopsis:             ByteString-backed Handles
category:             System
abi:                  d57d4a396475fc9bf01bcae7e9f35b5a
exposed:              True
exposed-modules:      Data.ByteString.Handle
hidden-modules:
    Data.ByteString.Handle.Read Data.ByteString.Handle.Write

import-dirs:          /usr/lib/ghc-8.10.4/site-local/bytestring-handle-0.1.0.6
library-dirs:         /usr/lib/ghc-8.10.4/site-local/bytestring-handle-0.1.0.6
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.4/bytestring-handle-0.1.0.6

hs-libraries:         HSbytestring-handle-0.1.0.6-5Wc1ZXhmhAZ4GPJQSe165h
depends:              base-4.14.1.0 bytestring-0.10.12.0
haddock-interfaces:
    /usr/share/doc/haskell-bytestring-handle/html/bytestring-handle.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-handle/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
